@@ -56,6 +56,8 @@ class DiscordInteractionsBlueprint:
         default_member_permissions=None,
         dm_permission=None,
         permissions=None,
+        name_localizations=None,
+        description_localizations=None,
     ):
         """
         Create and add a new :class:`ApplicationCommand`.
@@ -66,8 +68,12 @@ class DiscordInteractionsBlueprint:
             Function to execute when the command is run.
         name
             The name of the command, as displayed in the Discord client.
+        name_localizations
+            A dictionary of localizations for the name of the command.
         description
             The description of the command.
+        description_localizations
+            A dictionary of localizations for the description of the command.
         options
             A list of options for the command, overriding the function's
             keyword arguments.
@@ -96,6 +102,8 @@ class DiscordInteractionsBlueprint:
             default_member_permissions,
             dm_permission,
             permissions,
+            name_localizations,
+            description_localizations,
             self,
         )
         self.discord_commands[command.name] = command
@@ -125,6 +133,8 @@ class DiscordInteractionsBlueprint:
         default_member_permissions=None,
         dm_permission=None,
         permissions=None,
+        name_localizations=None,
+        description_localizations=None,
     ):
         """
         Decorator to create a new :class:`Command`.
@@ -133,8 +143,12 @@ class DiscordInteractionsBlueprint:
         ----------
         name
             The name of the command, as displayed in the Discord client.
+        name_localizations
+            A dictionary of localizations for the name of the command.
         description
             The description of the command.
+        description_localizations
+            A dictionary of localizations for the description of the command.
         options
             A list of options for the command, overriding the function's
             keyword arguments.
@@ -166,6 +180,8 @@ class DiscordInteractionsBlueprint:
                 default_member_permissions,
                 dm_permission,
                 permissions,
+                name_localizations,
+                description_localizations,
             )
             return command
 
@@ -180,6 +196,8 @@ class DiscordInteractionsBlueprint:
         default_member_permissions=None,
         dm_permission=None,
         permissions=None,
+        name_localizations=None,
+        description_localizations=None,
     ):
         """
         Create a new :class:`SlashCommandGroup`
@@ -189,8 +207,12 @@ class DiscordInteractionsBlueprint:
         ----------
         name
             The name of the command group, as displayed in the Discord client.
+        name_localizations
+            A dictionary of localizations for the name of the command group.
         description
             The description of the command group.
+        description_localizations
+            A dictionary of localizations for the description of the command group.
         is_async
             Whether the subgroup should be considered async (if subcommands
             get an :class:`.AsyncContext` instead of a :class:`Context`.)
@@ -212,6 +234,8 @@ class DiscordInteractionsBlueprint:
             default_member_permissions,
             dm_permission,
             permissions,
+            name_localizations,
+            description_localizations,
         )
         self.discord_commands[name] = group
         return group
@@ -404,7 +428,6 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
             response = requests.put(
                 url, json=overwrite_data, headers=self.auth_headers(app)
             )
-            self.throttle(response)
 
             try:
                 response.raise_for_status()
@@ -414,6 +437,8 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
                     f"{response.status_code} {response.text}"
                 )
 
+            self.throttle(response)
+
             for command in response.json():
                 if command["name"] in app.discord_commands:
                     app.discord_commands[command["name"]].id = command["id"]
@@ -421,23 +446,28 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
             for command in app.discord_commands.values():
                 command.id = command.name
 
-        for command in app.discord_commands.values():
-            if not app.config["DONT_REGISTER_WITH_DISCORD"]:
-                response = requests.put(
-                    url + "/" + command.id + "/permissions",
-                    json={"permissions": command.dump_permissions()},
-                    headers=self.auth_headers(app),
-                )
-                self.throttle(response)
-
-                try:
-                    response.raise_for_status()
-                except requests.exceptions.HTTPError:
-                    raise ValueError(
-                        f"Unable to register permissions for {command.id}:"
-                        f"{response.status_code} {response.text}"
+        if guild_id:
+            for command in app.discord_commands.values():
+                if (
+                    not app.config["DONT_REGISTER_WITH_DISCORD"]
+                    and command.permissions is not None
+                ):
+                    response = requests.put(
+                        url + "/" + command.id + "/permissions",
+                        json={"permissions": command.dump_permissions()},
+                        headers=self.auth_headers(app),
                     )
 
+                    try:
+                        response.raise_for_status()
+                    except requests.exceptions.HTTPError:
+                        raise ValueError(
+                            f"Unable to register permissions for {command.id}:"
+                            f"{response.status_code} {response.text}"
+                        )
+
+                    self.throttle(response)
+
     def update_slash_commands(self, *args, **kwargs):
         """
         Deprecated! As of v1.1.0, ``update_slash_commands`` has been renamed to
@@ -470,7 +500,11 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
         # rate_limit_bucket = response.headers["X-RateLimit-Bucket"]
 
         if not rate_limit_remaining:
-            time.sleep(max(rate_limit_reset - time.time(), 0))
+            wait_time = rate_limit_reset - time.time()
+            warnings.warn(
+                f"You are being rate limited. Waiting {int(wait_time)} seconds..."
+            )
+            time.sleep(max(wait_time, 0))
 
     def register_blueprint(self, blueprint, app=None):
         """
